Crate double_derive

Crate double_derive 

Attribute Macros

dummies
Generates a “dummy” implementation for each method in a trait using unimplemented!(). The main use case is to greate specialized test doubles for implementing the trait without worrying the need to explicitly implement methods, which are not invoked by the test.