dummies

Attribute Macro dummies 

#[dummies]
Generates a “dummy” implementation for each method in a trait using unimplemented!(). The main use case is to greate specialized test doubles for implementing the trait without worrying the need to explicitly implement methods, which are not invoked by the test.

  • Existing default implementations are respected and not overridden.
  • async methods are supported
  • Methods returning impl Traits are not supported, with the exception of impl Future and impl Iterator.
  • Dummy implements the trait