#[dummies]Expand description
Generates a “dummy” implementation for each method in a trait using unimplemented!(). The main
use case is to greate specialized test doubles for implementing the trait without worrying the
need to explicitly implement methods, which are not invoked by the test.
- Existing default implementations are respected and not overridden.
asyncmethods are supported- Methods returning
implTraits are not supported, with the exception ofimpl Futureandimpl Iterator. - Dummy implements the trait